Best practices
==============

.. todo:: Work in progress!

For consistency, we invite you to respect these guidelines while developing new plugins.

Style
-----

- `Black <https://black.readthedocs.io/>`_
- `PEP 8 <https://www.python.org/dev/peps/pep-0008/>`_
- `Google Python Style Guide <http://google.github.io/styleguide/pyguide.html>`_

Tests
-----

- Write tests. We use `pytest <https://docs.pytest.org/en/latest/>`_.

Documentation
-------------

- Write good documentation. We use the `Google Style Python Docstrings <https://sphinxcontrib-napoleon.readthedocs.io/en/latest/example_google.html>`_.